@@ -21,66 +21,76 @@ setGeneric("sum",
            useAsDefault = FALSE)
 
 setMethod("sum",
-          signature(x = "vector", na.rm = "logical"),
+          signature(x     = "vector",
+                    na.rm = "logical"),
           function(x, na.rm) {
               #cat(match.call()[[1]], "(vector, logical)", "\n")
               #cat("\tx = ", x, "\n")
               #cat("\tna.rm = ", na.rm, "\n")
+              if (is.logical(x)) {
+                  mode(x) <- "integer"
+              }
+
               return(base::sum(x, na.rm = na.rm))
           })
 
 setMethod("sum",
-          signature(x = "vector", na.rm = "missing"),
+          signature(x     = "vector",
+                    na.rm = "missing"),
           function(x, na.rm) {
               #cat(match.call()[[1]], "(vector, missing)", "\n")
               callGeneric(x, na.rm)
           })
 
 setMethod("sum",
-          signature(x = "matrix", na.rm = "logical"),
+          signature(x     = "matrix",
+                    na.rm = "logical"),
           function(x, na.rm) {
               #cat(match.call()[[1]], "(matrix, logical)", "\n")
               #cat("\tx =\n"); print(x); cat("\n")
               #cat("\tna.rm = ", na.rm, "\n")
+              if (is.logical(x)) {
+                  mode(x) <- "integer"
+              }
+
               return(apply(x, 2, base::sum, na.rm = na.rm))
           })
 
 setMethod("sum",
-          signature(x = "matrix", na.rm = "missing"),
+          signature(x     = "matrix",
+                    na.rm = "missing"),
           function(x, na.rm) {
               #cat(match.call()[[1]], "(matrix, missing)", "\n")
               callGeneric(x, na.rm)
           })
 
 setMethod("sum",
-          signature(x = "array", na.rm = "logical"),
+          signature(x     = "array",
+                    na.rm = "logical"),
           function(x, na.rm) {
               stop(sprintf("method not implemented for %s argument",
                            data.class(x)))
           })
 
 setMethod("sum",
-          signature(x = "array", na.rm = "missing"),
+          signature(x     = "array",
+                    na.rm = "missing"),
           function(x, na.rm) {
               #cat(match.call()[[1]], "(array, missing)", "\n")
               callGeneric(x, na.rm)
           })
 
 setMethod("sum",
-          signature(x = "logical"),
+          signature(x     = "ANY",
+                    na.rm = "ANY"),
           function(x, na.rm) {
-              stop(sprintf("argument %s cannot be logical", sQuote("x")))
-          })
-
-setMethod("sum",
-          signature(x = "ANY"),
-          function(x, na.rm) {
-              #cat(match.call()[[1]], "(ANY)", "\n")
+              #cat(match.call()[[1]], "(ANY, ANY)", "\n")
               stop(sprintf("method not defined for %s argument", data.class(x)))
           })
 
 setMethod("sum",
-          signature(x = "missing"),
+          signature(x     = "missing",
+                    na.rm = "ANY"),
           function(x, na.rm) {
               stop(sprintf("argument %s missing", sQuote("x")))
           })
